@@ -7,19 +7,18 @@ namespace PhpMyAdmin\Database;
 use PhpMyAdmin\DatabaseInterface;
 use PhpMyAdmin\Html\Generator;
 use PhpMyAdmin\Message;
-use PhpMyAdmin\Response;
+use PhpMyAdmin\ResponseRenderer;
 use PhpMyAdmin\Template;
-use PhpMyAdmin\Url;
 use PhpMyAdmin\Util;
-use const ENT_QUOTES;
+
+use function __;
 use function count;
 use function explode;
-use function htmlentities;
 use function htmlspecialchars;
 use function in_array;
-use function mb_strpos;
 use function mb_strtoupper;
 use function sprintf;
+use function str_contains;
 use function trim;
 
 /**
@@ -39,13 +38,13 @@ class Triggers
     /** @var Template */
     private $template;
 
-    /** @var Response */
+    /** @var ResponseRenderer */
     private $response;
 
     /**
      * @param DatabaseInterface $dbi      DatabaseInterface instance.
      * @param Template          $template Template instance.
-     * @param Response          $response Response instance.
+     * @param ResponseRenderer  $response Response instance.
      */
     public function __construct(DatabaseInterface $dbi, Template $template, $response)
     {
@@ -56,12 +55,10 @@ class Triggers
 
     /**
      * Main function for the triggers functionality
-     *
-     * @return void
      */
-    public function main()
+    public function main(): void
     {
-        global $db, $table, $text_dir, $PMA_Theme;
+        global $db, $table;
 
         /**
          * Process all requests
@@ -90,28 +87,18 @@ class Triggers
             'table' => $table,
             'items' => $items,
             'rows' => $rows,
-            'select_all_arrow_src' => $PMA_Theme->getImgPath() . 'arrow_' . $text_dir . '.png',
-        ]);
-
-        echo $this->template->render('database/triggers/footer', [
-            'db' => $db,
-            'table' => $table,
             'has_privilege' => $hasTriggerPrivilege,
         ]);
     }
 
     /**
      * Handles editor requests for adding or editing an item
-     *
-     * @return void
      */
-    public function handleEditor()
+    public function handleEditor(): void
     {
         global $db, $errors, $message, $table;
 
-        if (! empty($_POST['editor_process_add'])
-            || ! empty($_POST['editor_process_edit'])
-        ) {
+        if (! empty($_POST['editor_process_add']) || ! empty($_POST['editor_process_edit'])) {
             $sql_query = '';
 
             $item_query = $this->getQueryFromRequest();
@@ -145,7 +132,9 @@ class Triggers
                             // new one. Try to restore the backup query.
                             $result = $this->dbi->tryQuery($create_item);
 
-                            $errors = $this->checkResult($result, $create_item, $errors);
+                            if (! $result) {
+                                $errors = $this->checkResult($create_item, $errors);
+                            }
                         } else {
                             $message = Message::success(
                                 __('Trigger %1$s has been modified.')
@@ -190,6 +179,7 @@ class Triggers
                 foreach ($errors as $string) {
                     $message->addHtml('<li>' . $string . '</li>');
                 }
+
                 $message->addHtml('</ul>');
             }
 
@@ -206,10 +196,9 @@ class Triggers
 
                         $trigger = $value;
                     }
+
                     $insert = false;
-                    if (empty($table)
-                        || ($trigger !== false && $table == $trigger['table'])
-                    ) {
+                    if (empty($table) || ($trigger !== false && $table == $trigger['table'])) {
                         $insert = true;
                         $hasTriggerPrivilege = Util::currentUserHasPrivilege('TRIGGER', $db, $table);
                         $this->response->addJSON(
@@ -232,12 +221,14 @@ class Triggers
                             )
                         );
                     }
+
                     $this->response->addJSON('insert', $insert);
                     $this->response->addJSON('message', $output);
                 } else {
                     $this->response->addJSON('message', $message);
                     $this->response->setRequestStatus(false);
                 }
+
                 $this->response->addJSON('tableType', 'triggers');
                 exit;
             }
@@ -246,7 +237,8 @@ class Triggers
         /**
          * Display a form used to add/edit a trigger, if necessary
          */
-        if (! count($errors)
+        if (
+            ! count($errors)
             && (! empty($_POST['editor_process_add'])
             || ! empty($_POST['editor_process_edit'])
             || (empty($_REQUEST['add_item'])
@@ -265,9 +257,7 @@ class Triggers
             $mode = 'add';
         } elseif (! empty($_REQUEST['edit_item'])) {
             $title = __('Edit trigger');
-            if (! empty($_REQUEST['item_name'])
-                && empty($_POST['editor_process_edit'])
-            ) {
+            if (! empty($_REQUEST['item_name']) && empty($_POST['editor_process_edit'])) {
                 $item = $this->getDataFromName($_REQUEST['item_name']);
                 if ($item !== null) {
                     $item['item_original_name'] = $item['item_name'];
@@ -275,9 +265,11 @@ class Triggers
             } else {
                 $item = $this->getDataFromRequest();
             }
+
             $mode = 'edit';
         }
-        $this->sendEditor($mode, $item, $title, $db);
+
+        $this->sendEditor($mode, $item, $title, $db, $table);
     }
 
     /**
@@ -325,19 +317,20 @@ class Triggers
 
             $temp = $value;
         }
+
         if (empty($temp)) {
             return null;
         }
 
         $retval = [];
-        $retval['create']                  = $temp['create'];
-        $retval['drop']                    = $temp['drop'];
-        $retval['item_name']               = $temp['name'];
-        $retval['item_table']              = $temp['table'];
-        $retval['item_action_timing']      = $temp['action_timing'];
+        $retval['create'] = $temp['create'];
+        $retval['drop'] = $temp['drop'];
+        $retval['item_name'] = $temp['name'];
+        $retval['item_table'] = $temp['table'];
+        $retval['item_action_timing'] = $temp['action_timing'];
         $retval['item_event_manipulation'] = $temp['event_manipulation'];
-        $retval['item_definition']         = $temp['definition'];
-        $retval['item_definer']            = $temp['definer'];
+        $retval['item_definition'] = $temp['definition'];
+        $retval['item_definer'] = $temp['definer'];
 
         return $retval;
     }
@@ -345,128 +338,28 @@ class Triggers
     /**
      * Displays a form used to add/edit a trigger
      *
-     * @param string $mode If the editor will be used to edit a trigger
-     *                     or add a new one: 'edit' or 'add'.
-     * @param array  $item Data for the trigger returned by getDataFromRequest()
-     *                     or getDataFromName()
-     *
-     * @return string HTML code for the editor.
+     * @param string $db
+     * @param string $table
+     * @param string $mode  If the editor will be used to edit a trigger or add a new one: 'edit' or 'add'.
+     * @param array  $item  Data for the trigger returned by getDataFromRequest() or getDataFromName()
      */
-    public function getEditorForm($mode, array $item)
+    public function getEditorForm($db, $table, $mode, array $item): string
     {
-        global $db, $table;
-
-        $modeToUpper = mb_strtoupper($mode);
-
-        // Escape special characters
-        $need_escape = [
-            'item_original_name',
-            'item_name',
-            'item_definition',
-            'item_definer',
-        ];
-        foreach ($need_escape as $key => $index) {
-            $item[$index] = htmlentities($item[$index], ENT_QUOTES, 'UTF-8');
-        }
-        $original_data = '';
-        if ($mode === 'edit') {
-            $original_data = "<input name='item_original_name' "
-                           . "type='hidden' value='" . $item['item_original_name'] . "'>\n";
-        }
-        $query  = 'SELECT `TABLE_NAME` FROM `INFORMATION_SCHEMA`.`TABLES` ';
-        $query .= "WHERE `TABLE_SCHEMA`='" . $this->dbi->escapeString($db) . "' ";
-        $query .= "AND `TABLE_TYPE` IN ('BASE TABLE', 'SYSTEM VERSIONED')";
+        $query = 'SELECT `TABLE_NAME` FROM `INFORMATION_SCHEMA`.`TABLES` ';
+        $query .= 'WHERE `TABLE_SCHEMA`=\'' . $this->dbi->escapeString($db) . '\' ';
+        $query .= 'AND `TABLE_TYPE` IN (\'BASE TABLE\', \'SYSTEM VERSIONED\')';
         $tables = $this->dbi->fetchResult($query);
 
-        // Create the output
-        $retval  = '';
-        $retval .= '<!-- START ' . $modeToUpper . " TRIGGER FORM -->\n\n";
-        $retval .= '<form class="rte_form" action="' . Url::getFromRoute('/database/triggers')
-            . '" method="post">' . "\n";
-        $retval .= "<input name='" . $mode . "_item' type='hidden' value='1'>\n";
-        $retval .= $original_data;
-        $retval .= Url::getHiddenInputs($db, $table) . "\n";
-        $retval .= "<fieldset>\n";
-        $retval .= '<legend>' . __('Details') . "</legend>\n";
-        $retval .= "<table class='rte_table table table-borderless table-sm'>\n";
-        $retval .= "<tr>\n";
-        $retval .= '    <td>' . __('Trigger name') . "</td>\n";
-        $retval .= "    <td><input type='text' name='item_name' maxlength='64'\n";
-        $retval .= "               value='" . $item['item_name'] . "'></td>\n";
-        $retval .= "</tr>\n";
-        $retval .= "<tr>\n";
-        $retval .= '    <td>' . __('Table') . "</td>\n";
-        $retval .= "    <td>\n";
-        $retval .= "        <select name='item_table'>\n";
-        foreach ($tables as $key => $value) {
-            $selected = '';
-            if ($mode === 'add' && $value == $table) {
-                $selected = " selected='selected'";
-            } elseif ($mode === 'edit' && $value == $item['item_table']) {
-                $selected = " selected='selected'";
-            }
-            $retval .= '<option' . $selected . '>';
-            $retval .= htmlspecialchars($value);
-            $retval .= "</option>\n";
-        }
-        $retval .= "        </select>\n";
-        $retval .= "    </td>\n";
-        $retval .= "</tr>\n";
-        $retval .= "<tr>\n";
-        $retval .= '    <td>' . _pgettext('Trigger action time', 'Time') . "</td>\n";
-        $retval .= "    <td><select name='item_timing'>\n";
-        foreach ($this->time as $key => $value) {
-            $selected = '';
-            if (! empty($item['item_action_timing'])
-                && $item['item_action_timing'] == $value
-            ) {
-                $selected = " selected='selected'";
-            }
-            $retval .= '<option' . $selected . '>' . $value . '</option>';
-        }
-        $retval .= "    </select></td>\n";
-        $retval .= "</tr>\n";
-        $retval .= "<tr>\n";
-        $retval .= '    <td>' . __('Event') . "</td>\n";
-        $retval .= "    <td><select name='item_event'>\n";
-        foreach ($this->event as $key => $value) {
-            $selected = '';
-            if (! empty($item['item_event_manipulation'])
-                && $item['item_event_manipulation'] == $value
-            ) {
-                $selected = " selected='selected'";
-            }
-            $retval .= '<option' . $selected . '>' . $value . '</option>';
-        }
-        $retval .= "    </select></td>\n";
-        $retval .= "</tr>\n";
-        $retval .= "<tr>\n";
-        $retval .= '    <td>' . __('Definition') . "</td>\n";
-        $retval .= "    <td><textarea name='item_definition' rows='15' cols='40'>";
-        $retval .= $item['item_definition'];
-        $retval .= "</textarea></td>\n";
-        $retval .= "</tr>\n";
-        $retval .= "<tr>\n";
-        $retval .= '    <td>' . __('Definer') . "</td>\n";
-        $retval .= "    <td><input type='text' name='item_definer'\n";
-        $retval .= "               value='" . $item['item_definer'] . "'></td>\n";
-        $retval .= "</tr>\n";
-        $retval .= "</table>\n";
-        $retval .= "</fieldset>\n";
-        if ($this->response->isAjax()) {
-            $retval .= "<input type='hidden' name='editor_process_" . $mode . "'\n";
-            $retval .= "       value='true'>\n";
-            $retval .= "<input type='hidden' name='ajax_request' value='true'>\n";
-        } else {
-            $retval .= "<fieldset class='tblFooters'>\n";
-            $retval .= "    <input type='submit' name='editor_process_" . $mode . "'\n";
-            $retval .= "           value='" . __('Go') . "'>\n";
-            $retval .= "</fieldset>\n";
-        }
-        $retval .= "</form>\n\n";
-        $retval .= '<!-- END ' . $modeToUpper . " TRIGGER FORM -->\n\n";
-
-        return $retval;
+        return $this->template->render('database/triggers/editor_form', [
+            'db' => $db,
+            'table' => $table,
+            'is_edit' => $mode === 'edit',
+            'item' => $item,
+            'tables' => $tables,
+            'time' => $this->time,
+            'events' => $this->event,
+            'is_ajax' => $this->response->isAjax(),
+        ]);
     }
 
     /**
@@ -480,8 +373,7 @@ class Triggers
 
         $query = 'CREATE ';
         if (! empty($_POST['item_definer'])) {
-            if (mb_strpos($_POST['item_definer'], '@') !== false
-            ) {
+            if (str_contains($_POST['item_definer'], '@')) {
                 $arr = explode('@', $_POST['item_definer']);
                 $query .= 'DEFINER=' . Util::backquote($arr[0]);
                 $query .= '@' . Util::backquote($arr[1]) . ' ';
@@ -489,34 +381,33 @@ class Triggers
                 $errors[] = __('The definer must be in the "username@hostname" format!');
             }
         }
+
         $query .= 'TRIGGER ';
         if (! empty($_POST['item_name'])) {
             $query .= Util::backquote($_POST['item_name']) . ' ';
         } else {
             $errors[] = __('You must provide a trigger name!');
         }
-        if (! empty($_POST['item_timing'])
-            && in_array($_POST['item_timing'], $this->time)
-        ) {
+
+        if (! empty($_POST['item_timing']) && in_array($_POST['item_timing'], $this->time)) {
             $query .= $_POST['item_timing'] . ' ';
         } else {
             $errors[] = __('You must provide a valid timing for the trigger!');
         }
-        if (! empty($_POST['item_event'])
-            && in_array($_POST['item_event'], $this->event)
-        ) {
+
+        if (! empty($_POST['item_event']) && in_array($_POST['item_event'], $this->event)) {
             $query .= $_POST['item_event'] . ' ';
         } else {
             $errors[] = __('You must provide a valid event for the trigger!');
         }
+
         $query .= 'ON ';
-        if (! empty($_POST['item_table'])
-            && in_array($_POST['item_table'], $this->dbi->getTables($db))
-        ) {
+        if (! empty($_POST['item_table']) && in_array($_POST['item_table'], $this->dbi->getTables($db))) {
             $query .= Util::backquote($_POST['item_table']);
         } else {
             $errors[] = __('You must provide a valid table name!');
         }
+
         $query .= ' FOR EACH ROW ';
         if (! empty($_POST['item_definition'])) {
             $query .= $_POST['item_definition'];
@@ -528,18 +419,13 @@ class Triggers
     }
 
     /**
-     * @param resource|bool $result          Query result
-     * @param string        $createStatement Query
-     * @param array         $errors          Errors
+     * @param string $createStatement Query
+     * @param array  $errors          Errors
      *
      * @return array
      */
-    private function checkResult($result, $createStatement, array $errors)
+    private function checkResult($createStatement, array $errors)
     {
-        if ($result) {
-            return $errors;
-        }
-
         // OMG, this is really bad! We dropped the query,
         // failed to create a new one
         // and now even the backup query does not execute!
@@ -560,13 +446,12 @@ class Triggers
      * @param array|null $item  Data necessary to create the editor
      * @param string     $title Title of the editor
      * @param string     $db    Database
-     *
-     * @return void
+     * @param string     $table Table
      */
-    private function sendEditor($mode, ?array $item, $title, $db)
+    private function sendEditor($mode, ?array $item, $title, $db, $table): void
     {
         if ($item !== null) {
-            $editor = $this->getEditorForm($mode, $item);
+            $editor = $this->getEditorForm($db, $table, $mode, $item);
             if ($this->response->isAjax()) {
                 $this->response->addJSON('message', $editor);
                 $this->response->addJSON('title', $title);
@@ -574,10 +459,11 @@ class Triggers
                 echo "\n\n<h2>" . $title . "</h2>\n\n" . $editor;
                 unset($_POST);
             }
+
             exit;
         }
 
-        $message  = __('Error in processing request:') . ' ';
+        $message = __('Error in processing request:') . ' ';
         $message .= sprintf(
             __('No trigger with name %1$s found in database %2$s.'),
             htmlspecialchars(Util::backquote($_REQUEST['item_name'])),
@@ -612,29 +498,27 @@ class Triggers
             }
         }
 
-        $itemName = htmlspecialchars(Util::backquote($_GET['item_name']));
         if ($exportData !== false) {
-            $exportData = htmlspecialchars(trim($exportData));
-            $title = sprintf(__('Export of trigger %s'), $itemName);
+            $title = sprintf(__('Export of trigger %s'), htmlspecialchars(Util::backquote($itemName)));
 
             if ($this->response->isAjax()) {
-                $this->response->addJSON('message', $exportData);
+                $this->response->addJSON('message', htmlspecialchars(trim($exportData)));
                 $this->response->addJSON('title', $title);
 
                 exit;
             }
 
-            $exportData = '<textarea cols="40" rows="15" style="width: 100%;">'
-                . $exportData . '</textarea>';
-            echo "<fieldset>\n" . '<legend>' . $title . "</legend>\n"
-                . $exportData . "</fieldset>\n";
+            $this->response->addHTML($this->template->render('database/triggers/export', [
+                'data' => $exportData,
+                'item_name' => $itemName,
+            ]));
 
             return;
         }
 
         $message = sprintf(
             __('Error in processing request: No trigger with name %1$s found in database %2$s.'),
-            $itemName,
+            htmlspecialchars(Util::backquote($itemName)),
             htmlspecialchars(Util::backquote($db))
         );
         $message = Message::error($message);
@@ -646,6 +530,6 @@ class Triggers
             exit;
         }
 
-        echo $message->getDisplay();
+        $this->response->addHTML($message->getDisplay());
     }
 }
