@@ -1,18 +1,13 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
-/**
- * Holds the PhpMyAdmin\Properties\Options\Groups\OptionsPropertyRootGroup class
- *
- * @package PhpMyAdmin
- */
+
+declare(strict_types=1);
+
 namespace PhpMyAdmin\Properties\Options\Groups;
 
 use PhpMyAdmin\Properties\Options\OptionsPropertyGroup;
 
 /**
  * Group property item class of type root
- *
- * @package PhpMyAdmin
  */
 class OptionsPropertyRootGroup extends OptionsPropertyGroup
 {
@@ -28,6 +23,6 @@ class OptionsPropertyRootGroup extends OptionsPropertyGroup
      */
     public function getItemType()
     {
-        return "root";
+        return 'root';
     }
 }
