@@ -117,7 +117,7 @@ final class CustomServer implements Server
         try {
             $attestationCredential = $this->getAttestationCredential($attestationResponse);
         } catch (Throwable $exception) {
-            throw new WebAuthnException('Invalid authenticator response.');
+            throw new WebAuthnException('Invalid authenticator response.', (int) $exception->getCode(), $exception);
         }
 
         $creationOptions = json_decode($credentialCreationOptions, true);
